@@ -1,5 +1,5 @@
 import numpy as np
-from shancx.Calmetrics.metrics import Metrics
+from . import Metrics
 def cal_metrics(obs_v,pre_v):
     metrics = Metrics(obs_v.ravel(), pre_v.ravel())
     ts_score = np.around(metrics.cal_ts(),4)
