@@ -132,6 +132,27 @@ def Mul_sub(task, param_list, num=6):
             sys.exit(1)    
     print("All tasks completed")
 
+from concurrent.futures import ThreadPoolExecutor
+from itertools import product
+def Mul_TH(task, param_list, max_workers=6):
+    print(f"Thread num: {max_workers}")
+    validate_param_list(param_list)
+    task_args = [
+        (arg,) if len(param_list) == 1 else arg
+        for arg in (
+            param_list[0] if len(param_list) == 1 
+            else product(*param_list)
+        )
+    ]    
+    with ThreadPoolExecutor(max_workers) as ex:
+        try:
+            list(ex.map(task, task_args))
+        except KeyboardInterrupt:
+            print("\n用户中断操作")
+            ex.shutdown(wait=False)
+            sys.exit(1) 
+
+
 # import os
 # from datetime import datetime
 # from shancx.NN import _loggers
